@@ -16,12 +16,13 @@ R_CMethodDef CEntries[] = {
     {"crspl", (DL_FUNC) &crspl,8},
     {"predict_tprs", (DL_FUNC) &predict_tprs, 12},
     {"MinimumSeparation", (DL_FUNC) &MinimumSeparation, 7},
-    {"magic", (DL_FUNC) &magic, 18},
+    {"magic", (DL_FUNC) &magic, 19},
     {"mgcv_mmult", (DL_FUNC) &mgcv_mmult,8},
-    {"gdi1",(DL_FUNC) &gdi1,45},
+    {"mgcv_pmmult", (DL_FUNC) &mgcv_mmult,9},
+    {"gdi1",(DL_FUNC) &gdi1,46},
     {"R_cond",(DL_FUNC) &R_cond,5} ,
     {"pls_fit",(DL_FUNC)&pls_fit,10},
-    {"pls_fit1",(DL_FUNC)&pls_fit1,11},
+    {"pls_fit1",(DL_FUNC)&pls_fit1,12},
     {"tweedious",(DL_FUNC)&tweedious,8},
     {"psum",(DL_FUNC)&psum,4},
     {"get_detS2",(DL_FUNC)&get_detS2,12},
@@ -35,10 +36,10 @@ R_CMethodDef CEntries[] = {
     {"Rlanczos",(DL_FUNC)&Rlanczos,7},
     {"rksos",(DL_FUNC)&rksos,3},
     {"gen_tps_poly_powers",(DL_FUNC)&gen_tps_poly_powers,4},
-    {"sparse_penalty",(DL_FUNC)&sparse_penalty,9},
     {"k_nn",(DL_FUNC)&k_nn,8},
-    {"kba_nn",(DL_FUNC)&kba_nn,9},
-    {"Rkdtree",(DL_FUNC)&Rkdtree,7},
+    {"Rkdtree",(DL_FUNC)&Rkdtree,5},
+    {"Rkdnearest",(DL_FUNC)&Rkdnearest,9},
+    {"Rkradius",(DL_FUNC)&Rkradius,9},
     {"sspl_construct",(DL_FUNC)&sspl_construct,9},
     {"sspl_mapply",(DL_FUNC)&sspl_mapply,9},
     {"tri2nei",(DL_FUNC)&tri2nei,5},
@@ -46,6 +47,10 @@ R_CMethodDef CEntries[] = {
     {"boundary",(DL_FUNC)&boundary, 14},
     {"pde_coeffs",(DL_FUNC)&pde_coeffs, 9},
     {"gridder",(DL_FUNC)&gridder, 13},
+    {"row_block_reorder",(DL_FUNC)&row_block_reorder,5},
+    {"mgcv_pqr",(DL_FUNC)&mgcv_pqr,6},
+    {"getRpqr",(DL_FUNC)&getRpqr,6},
+    {"mgcv_pqrqy",(DL_FUNC)&mgcv_pqrqy,8},
     {NULL, NULL, 0}
 };
 
